##  Benefits
  * Sync transformation initiatives with Jira projects and Jira tickets, to-dos, and issues and vice versa.
  * Bundle Jira items under one initiative.
  * Connect multiple accounts to have visibility over work done by different teams, geographies, or projects under one transformation initiative.
  * Configure your progress based on meaningful completion indicators. For example, tickets “completed” or “assessed,” but not “created.”
  * Track progress based on your indicators, ensuring visibility into initiative execution in SAP LeanIX.
